==> search-client-library-1.0.2-20131018.225216-59-sources.jar: org/gcube/search/client/library/proxies/SearchCLDefaultProxy.java <==
package org.gcube.search.client.library.proxies;

import gr.uoa.di.madgik.grs.record.GenericRecord;

import java.net.URI;
import java.net.URISyntaxException;
import java.util.concurrent.TimeUnit;

import org.gcube.common.clients.delegates.ProxyDelegate;
import org.gcube.data.streams.Stream;
import org.gcube.search.client.library.exceptions.SearchException;
import org.gcube.search.client.library.stubs.SearchStub;
import org.gcube.search.client.library.beans.Types;
import org.gcube.common.clients.Call;


import static org.gcube.data.streams.dsl.Streams.*;

public class SearchCLDefaultProxy implements SearchCLProxyI {
	
	private final ProxyDelegate<SearchStub> delegate;
	
	public SearchCLDefaultProxy(ProxyDelegate<SearchStub> config) {
		this.delegate = config;
	}

	public Stream<GenericRecord> search(final String query) throws SearchException {
		Call<SearchStub,Types.SearchResponse> call = new Call<SearchStub,Types.SearchResponse>() {
			@Override
			public Types.SearchResponse call(SearchStub endpoint) {
				return endpoint.search(query);
			}
		};
		
		Types.SearchResponse searchResponse = null;
		try {
			searchResponse = delegate.make(call);
		} catch (Exception e1) {
			throw new SearchException(e1);
		}
		String rsLocator = searchResponse.epr;
		
		URI rsURI = null;
		try {
			rsURI = new URI(rsLocator);
		} catch (URISyntaxException e2) {
			throw new SearchException(e2);
		}
		Stream<GenericRecord> stream = convert(rsURI).of(GenericRecord.class).withTimeout(60,TimeUnit.SECONDS);
		return stream;
	}
	
}

==> search-client-library-1.1.0-20140205.223805-2-sources.jar: org/gcube/search/client/library/proxies/SearchCLDefaultProxy.java <==
package org.gcube.search.client.library.proxies;

import gr.uoa.di.madgik.grs.record.GenericRecord;

import java.net.URI;
import java.net.URISyntaxException;
import java.util.Set;
import java.util.concurrent.TimeUnit;

import org.gcube.common.clients.delegates.ProxyDelegate;
import org.gcube.data.streams.Stream;
import org.gcube.search.client.library.exceptions.SearchException;
import org.gcube.search.client.library.stubs.SearchStub;
import org.gcube.search.client.library.beans.Types;
import org.gcube.search.client.library.beans.Types.SearchSecRequest;
import org.gcube.common.clients.Call;


import static org.gcube.data.streams.dsl.Streams.*;

public class SearchCLDefaultProxy implements SearchCLProxyI {
	
	private final ProxyDelegate<SearchStub> delegate;
	
	public SearchCLDefaultProxy(ProxyDelegate<SearchStub> config) {
		this.delegate = config;
	}

	public Stream<GenericRecord> search(final String query) throws SearchException {
		Call<SearchStub,Types.SearchResponse> call = new Call<SearchStub,Types.SearchResponse>() {
			@Override
			public Types.SearchResponse call(SearchStub endpoint) {
				return endpoint.search(query);
			}
		};
		
		Types.SearchResponse searchResponse = null;
		try {
			searchResponse = delegate.make(call);
		} catch (Exception e1) {
			throw new SearchException(e1);
		}
		String rsLocator = searchResponse.epr;
		
		URI rsURI = null;
		try {
			rsURI = new URI(rsLocator);
		} catch (URISyntaxException e2) {
			throw new SearchException(e2);
		}
		Stream<GenericRecord> stream = convert(rsURI).of(GenericRecord.class).withTimeout(60,TimeUnit.SECONDS);
		return stream;
	}
	
	
	public Stream<GenericRecord> searchSec(final String query, final Set<String> sids) throws SearchException {
		
		Call<SearchStub,Types.SearchResponse> call = new Call<SearchStub,Types.SearchResponse>() {
			@Override
			public Types.SearchResponse call(SearchStub endpoint) {
				
				final SearchSecRequest searchRequest = new SearchSecRequest();
				searchRequest.query = query;
				if (sids != null) {
					searchRequest.sids = new String[sids.size()];
					int i = 0;
					for (String sid : sids)
						searchRequest.sids[i++] = sid;
				}
				return endpoint.searchSec(searchRequest);
			}
		};
		
		Types.SearchResponse searchResponse = null;
		try {
			searchResponse = delegate.make(call);
		} catch (Exception e1) {
			throw new SearchException(e1);
		}
		String rsLocator = searchResponse.epr;
		
		URI rsURI = null;
		try {
			rsURI = new URI(rsLocator);
		} catch (URISyntaxException e2) {
			throw new SearchException(e2);
		}
		Stream<GenericRecord> stream = convert(rsURI).of(GenericRecord.class).withTimeout(60,TimeUnit.SECONDS);
		return stream;
	}
	
}
